# serial 16

# Copyright (C) 2001, 2003, 2005, 2006, 2009 Free Software Foundation, Inc.
# This file is free software; the Free Software Foundation
# gives unlimited permission to copy and/or distribute it,
# with or without modifications, as long as this notice is preserved.

dnl From Volker Borchert.
dnl Determine whether rename works for source file names with a trailing slash.
dnl The rename from SunOS 4.1.1_U1 doesn't.
dnl
dnl If it doesn't, then define RENAME_TRAILING_SLASH_BUG and arrange
dnl to compile the wrapper function.
dnl

AC_DEFUN([gl_FUNC_RENAME],
[
  AC_REQUIRE([AC_CANONICAL_HOST])
  AC_REQUIRE([gl_STDIO_H_DEFAULTS])

  dnl SunOS 4.1.1_U1 mistakenly forbids rename("dir/","name").
  dnl Solaris 9 mistakenly allows rename("file/","name").
  AC_CACHE_CHECK([whether rename honors trailing slash on source],
    [gl_cv_func_rename_slash_src_works],
    [rm -rf conftest.f conftest.d1 conftest.d2
    touch conftest.f && mkdir conftest.d1 ||
      AC_MSG_ERROR([cannot create temporary files])
    AC_RUN_IFELSE([AC_LANG_PROGRAM([[
#       include <stdio.h>
#       include <stdlib.h>
]], [if (rename ("conftest.f/", "conftest.d2") == 0) return 1;
     if (rename ("conftest.d1/", "conftest.d2") != 0) return 2;])],
      [gl_cv_func_rename_slash_src_works=yes],
      [gl_cv_func_rename_slash_src_works=no],
      dnl When crosscompiling, assume rename is broken.
      [gl_cv_func_rename_slash_src_works="guessing no"])
    rm -rf conftest.f conftest.d1 conftest.d2
  ])
  if test "x$gl_cv_func_rename_slash_src_works" != xyes; then
    AC_LIBOBJ([rename])
    REPLACE_RENAME=1
    AC_DEFINE([RENAME_TRAILING_SLASH_BUG], [1],
      [Define if rename does not correctly handle slashes on the source
       argument, such as on Solaris 9 or cygwin 1.5.])
  fi

  AC_CACHE_CHECK([whether rename is broken when the destination exists],
    [gl_cv_func_rename_dest_exists_bug],
    [case "$host_os" in
      mingw*) gl_cv_func_rename_dest_exists_bug=yes ;;
      *) gl_cv_func_rename_dest_exists_bug=no ;;
    esac
  ])
  if test $gl_cv_func_rename_dest_exists_bug = yes; then
    AC_LIBOBJ([rename])
    REPLACE_RENAME=1
    AC_DEFINE([RENAME_DEST_EXISTS_BUG], [1],
      [Define if rename does not work when the destination file exists,
       as on Windows.])
  fi
])
